@@ -18,7 +18,7 @@
  *
  * May, 2000. Implemented on FreeBSD 4.0-RELEASE (Compaq Armada M700)
  *
-$Id: properties.c,v 1.28 2003/07/24 02:02:45 kevinv Exp $
+$Id: properties.c,v 1.30 2003/10/22 22:01:18 kevinv Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -333,8 +333,13 @@ prop_cb (BonoboUIComponent *uic,
   GtkWidget *widget;
   guint      percentage;
   gboolean   writable;
+  GConfClient *client;
+  gboolean   inhibit_command_line;
 
-  apm_readinfo (PANEL_APPLET (battstat->applet));
+  client = gconf_client_get_default ();
+  inhibit_command_line = gconf_client_get_bool (client, "/desktop/gnome/lockdown/inhibit_command_line", NULL);
+
+  apm_readinfo (PANEL_APPLET (battstat->applet), battstat);
 
 #ifdef __FreeBSD__
   percentage = apminfo.ai_batt_life;
@@ -475,7 +480,8 @@ prop_cb (BonoboUIComponent *uic,
   g_signal_connect (G_OBJECT(battstat->suspend_entry), "changed",
 		    G_CALLBACK(suspend_changed), battstat);
 
-  if ( ! key_writable (PANEL_APPLET (battstat->applet), "suspend_command")) {
+  if ( ! key_writable (PANEL_APPLET (battstat->applet), "suspend_command") ||
+      inhibit_command_line) {
 	  hard_set_sensitive (battstat->suspend_entry, FALSE);
 	  hard_set_sensitive (glade_xml_get_widget (glade_xml, "suspend_label"), FALSE);
   }
